@@ -18,10 +18,10 @@ class KontactSettingsDialogPrivate : public KontactKCMultiDialogPrivate
     friend class PageNode;
     Q_DECLARE_PUBLIC(KontactSettingsDialog)
 protected:
-    KontactSettingsDialogPrivate(KontactSettingsDialog *parent);
+    explicit KontactSettingsDialogPrivate(KontactSettingsDialog *parent);
 
     QStringList registeredComponents;
-    QList<QPair<KPluginMetaData, QVector<KPluginMetaData>>> componentsMetaData;
+    QList<QPair<KPluginMetaData, QList<KPluginMetaData>>> componentsMetaData;
     bool firstshow = true;
 
     KPageWidgetItem *createPageItem(KPageWidgetItem *parentItem, const QString &name, const QString &comment, const QString &iconName);
